function(cet_generate_sphinxdocs)
  cet_find_package(sphinx-doc 3.0 REQUIRED)
  cmake_parse_arguments(PARSE_ARGV 0 CGS "NO_ALL;NO_INSTALL;QUIET;VERBOSE"
    "CACHE_DIR;CONF_DIR;SOURCE_DIR;TARGET_STEM;TARGETS_VAR"
    "OUTPUT_FORMATS")
  if (NOT CGS_CACHE_DIR)
    if (CGS_BUILD_DIR)
      get_filename_component(CGS_CACHE_DIR "${CGS_CACHE_DIR}" DIRECTORY)
      string(JOIN "/" CGS_CACHE_DIR "${CGS_CACHE_DIR}" "_doctrees")
    else()
      set(CGS_CACHE_DIR "${CMAKE_CURRENT_BUILD_DIR}/_doctrees")
    endif()
  endif()
  if (NOT CGS_SOURCE_DIR)
    set(CGS_SOURCE_DIR "${CMAKE_CURRENT_SOURCE_DIR}")
  endif()
  if (NOT CGS_OUTPUT_FORMATS)
    set(CGS_OUTPUT_FORMATS html)
  endif()
  if (NOT CGS_NO_ALL)
    set(all_arg ALL)
  endif()
  if (CGS_QUIET AND CGS_VERBOSE)
    message(SEND_ERROR "QUIET and VERBOSE are mutually exclusive")
  elseif (CGS_QUIET)
    set(quiet_verbose -q)
  elseif (CGS_VERBOSE MATCHES "^-v+$")
    set(quiet_verbose "${CGS_VERBOSE}")
  elseif (CGS_VERBOSE MATCHES "^[0-9]+$")
    string(REPEAT "v" ${CGS_VERBOSE} quiet_verbose)
    if (quiet_verbose)
      string(PREPEND quiet_verbose "-")
    endif()
  elseif (CGS_VERBOSE)
    set(quiet_verbose -v)
  endif()
  cet_passthrough(IN_PLACE KEYWORD -c CGS_CONF_DIR)
  cet_passthrough(IN_PLACE KEYWORD -d CGS_CACHE_DIR)
  if (NOT CGS_TARGET_STEM)
    cet_package_path(current_directory SOURCE)
    string(REPLACE "/" "_" CGS_TARGET_STEM "${current_directory}")
  endif()
  set(targets)
  foreach (format IN LISTS CGS_OUTPUT_FORMATS)
    string(JOIN "/" sources ${CGS_CONF_DIR} "conf.py")
    set(target "${TARGET_STEM}_format")
    add_custom_target(${target} ${all_arg}
      sphinx-doc::sphinx-build
      ${quiet_verbose} "${CGS_CONF_DIR}" "${CGS_CACHE_DIR}"
      "${CGS_SOURCE_DIR}" "${CMAKE_CURRENT_BINARY_DIR}/${format}"
      COMMENT "Building ${format} documentation with Sphinx"
      VERBATIM
      SOURCES "${sources}"
      COMMAND_EXPAND_LISTS
      )
    list(APPEND targets ${target})
  endforeach()
  if (CGS_TARGETS_VAR)
    set(${CGS_TARGETS_VAR} "${targets}" PARENT_SCOPE)
  endif()
endfunction()
